@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 """JSONBourne + Pydantic"""
+from __future__ import annotations
 
 from functools import lru_cache
 from pprint import pformat
@@ -22,21 +23,26 @@ from jsonbourne.core import JSON, JsonObj
 JsonBaseModelT = TypeVar("JsonBaseModelT", bound="JsonBaseModel")
 
 __all__ = (
-    "__pydantic_version__",
+    "JsonBaseConfig",
     "JsonBaseModelDefaultConfig",
     "JsonBaseModel",
     "JsonBaseModelT",
     "JsonBaseSettings",
+    "JsonGenericModel",
+    # pydantic
+    "__pydantic_version__",
+    "BaseConfig",
     "BaseModel",
     "BaseSettings",
+    "BaseSettings",
+    "Extra",
     "Field",
-    "ValidationError",
-    "JsonGenericModel",
     "GenericModel",
+    "ValidationError",
 )
 
 
-class JsonBaseModelDefaultConfig(BaseConfig):
+class JsonBaseConfig(BaseConfig):
     """Pydantic model config class for JsonBaseModel; can be overridden"""
 
     # Sometimes hypothesis breaks and will try to add an attribute to
@@ -50,10 +56,14 @@ class JsonBaseModelDefaultConfig(BaseConfig):
     use_enum_values = True
 
 
-class JsonBaseModel(BaseModel, JsonObj):  # type: ignore
+class JsonBaseModelDefaultConfig(JsonBaseConfig):
+    ...
+
+
+class JsonBaseModel(BaseModel, JsonObj):  # type: ignore[misc, type-arg]
     """Hybrid `pydantic.BaseModel` and `jsonbourne.JsonObj`"""
 
-    Config = JsonBaseModelDefaultConfig
+    Config = JsonBaseConfig
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         """Construct a JsonBaseModel and allow for `__post_init__` functions"""
@@ -344,13 +354,13 @@ class JsonBaseModel(BaseModel, JsonObj):  # type: ignore
         return self.__class__._cls_field_names()
 
 
-class JsonBaseSettings(BaseSettings, JsonBaseModel):  # type: ignore
+class JsonBaseSettings(BaseSettings, JsonBaseModel):  # type: ignore[misc]
     """pydantic BaseSettings + JsonBaseModel"""
 
     ...
 
 
-class JsonGenericModel(GenericModel, JsonBaseModel):  # type: ignore
+class JsonGenericModel(GenericModel, JsonBaseModel):  # type: ignore[misc]
     """Hybrid `pydantic.generics.GenericModel` and `jsonbourne.JsonObj`"""
 
     ...
